#[non_exhaustive]pub enum ProfileError {
Io(Error),
Json(Error),
HomeDirNotFound,
NotFound {
path: PathBuf,
},
InvalidFilename(String),
}Expand description
Errors that can occur when reading or writing profile files.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Io(Error)
An I/O error occurred while reading or writing a profile file.
Json(Error)
A profile file contained invalid JSON.
HomeDirNotFound
The user’s home directory could not be determined.
NotFound
The requested profile file was not found.
InvalidFilename(String)
The filename is invalid (contains path separators, .., or is absolute).